@@ -126,14 +126,15 @@ class Garmin:
         self.garmin_connect_sso_url = "sso.garmin.com/sso"
         self.garmin_connect_modern_url = "connect.garmin.com/modern"
         self.garmin_connect_css_url = "https://static.garmincdn.com/com.garmin.connect/ui/css/gauth-custom-v1.2-min.css"
+        self.garmin_connect_login_url = self.garmin_connect_base_url + "/en-US/signin"
 
         if self.is_cn:
             self.garmin_connect_base_url = "https://connect.garmin.cn"
             self.garmin_connect_sso_url = "sso.garmin.cn/sso"
             self.garmin_connect_modern_url = "connect.garmin.cn/modern"
             self.garmin_connect_css_url = "https://static.garmincdn.cn/cn.garmin.connect/ui/css/gauth-custom-v1.2-min.css"
+            self.garmin_connect_login_url = self.garmin_connect_base_url + "/zh-CN/signin"
 
-        self.garmin_connect_login_url = self.garmin_connect_base_url + "/en-US/signin"
         self.garmin_connect_sso_login = "signin"
 
         self.garmin_connect_devices_url = (
@@ -178,6 +179,10 @@ class Garmin:
             "proxy/wellness-service/wellness/bodyBattery/reports/daily"
         )
 
+        self.garmin_connect_blood_pressure_endpoint = (
+            "proxy/bloodpressure-service/bloodpressure/range"
+        )
+
         self.garmin_connect_goals_url = "proxy/goal-service/goal/goals"
 
         self.garmin_connect_rhr_url = "proxy/userstats-service/wellness/daily"
@@ -191,6 +196,9 @@ class Garmin:
         self.garmin_connect_user_summary_chart = (
             "proxy/wellness-service/wellness/dailySummaryChart"
         )
+        self.garmin_connect_floors_chart_daily_url = (
+            "proxy/wellness-service/wellness/floorsChartData/daily"
+        )
         self.garmin_connect_heartrates_daily_url = (
             "proxy/wellness-service/wellness/dailyHeartRate"
         )
@@ -451,6 +459,14 @@ class Garmin:
 
         return self.modern_rest_client.get(url, params=params).json()
 
+    def get_floors(self, cdate):
+        """Fetch available floors data 'cDate' format 'YYYY-MM-DD'."""
+
+        url = f'{self.garmin_connect_floors_chart_daily_url}/{cdate}'
+        logger.debug("Requesting floors data")
+
+        return self.modern_rest_client.get(url).json()
+
     def get_daily_steps(self, start, end):
         """Fetch available steps data 'start' and 'end' format 'YYYY-MM-DD'."""
 
@@ -500,6 +516,17 @@ class Garmin:
 
         return self.modern_rest_client.get(url, params=params).json()
 
+    def get_blood_pressure(self, startdate: str, enddate=None) -> Dict[str, Any]:
+        """Returns blood pressure by day for 'startdate' format 'YYYY-MM-DD' through enddate 'YYYY-MM-DD'"""
+
+        if enddate is None:
+            enddate = startdate
+        url = f"{self.garmin_connect_blood_pressure_endpoint}/{startdate}/{enddate}"
+        params = {"includeAll": True}
+        logger.debug("Requesting blood pressure data")
+
+        return self.modern_rest_client.get(url, params=params).json()
+
     def get_max_metrics(self, cdate: str) -> Dict[str, Any]:
         """Return available max metric data for 'cdate' format 'YYYY-MM-DD'."""
 
@@ -968,4 +995,4 @@ class GarminConnectAuthenticationError(Exception):
 
 
 class GarminConnectInvalidFileFormatError(Exception):
-    """Raised when an invalid file format is passed to upload."""
\ No newline at end of file
+    """Raised when an invalid file format is passed to upload."""
